@@ -1,11 +1,14 @@
 package MetaCPAN::Role::Fastly;
-$MetaCPAN::Role::Fastly::VERSION = '0.02';
+$MetaCPAN::Role::Fastly::VERSION = '0.03';
 # COPY BELOW HERE INTO MetaCPAN::Role::Fastly
 
 use Moose::Role;
-use Net::Fastly;
+use Net::Fastly 1.05;
 use Carp;
 
+# For dzil [AutoPreq]
+use MooseX::Fastly::Role 0.01;
+
 with 'MooseX::Fastly::Role';
 
 =head1 NAME
