@@ -1,7 +1,10 @@
 package MetaCPAN::Role::Fastly::Catalyst;
-$MetaCPAN::Role::Fastly::Catalyst::VERSION = '0.02';
+$MetaCPAN::Role::Fastly::Catalyst::VERSION = '0.03';
 use Moose::Role;
 
+# For dzil [AutoPreq]
+use CatalystX::Fastly::Role::Response 0.04;
+
 with 'MetaCPAN::Role::Fastly';
 with 'CatalystX::Fastly::Role::Response';
 
